Task: Multiwoz v2.2
===============
Description: Version of Multiwoz 2.0 dataset as cleaned by Google and structured to the Schema-Guided Dataset format.

From https://github.com/budzianowski/multiwoz/tree/master/data/MultiWOZ\_2.2 

License: MIT

Link: https://aclanthology.org/2020.nlp4convai-1.13.pdf 

Tags: #TOD #Multiwoz

